==> humhub-1.17.4.zip: humhub-1.17.4/protected/humhub/modules/admin/messages/zh-CN/settings.php <==
<?php

return [
    '1 month' => '1个月',
    '1 week' => '1周',
    '1 year' => '1年',
    '2 weeks' => '两周',
    '3 months' => '3个月',
    '6 months' => '6个月',
    '<strong>Confirm</strong> image deletion' => '<strong>确认</strong> 删除图片',
    'Add OEmbed provider' => '增加 OEmbed 供应商',
    'Add new provider' => '增加新的供应商',
    'Advanced Settings' => '高级设置',
    'Allow Self-Signed Certificates?' => '允许自己签名的证书吗？',
    'Allowed file extensions' => '允许文件扩展名',
    'Appearance Settings' => '外观设置',
    'Auto format based on user language - Example: {example}' => '根据用户语言自动格式化 - 例如：{example}',
    'Back to overview' => '返回概览',
    'Base URL' => '基础URL',
    'Cache Backend' => '缓存后台',
    'Comma separated list. Leave empty to allow all.' => '逗号分割列表。留空为允许所有。',
    'Currently no provider active!' => '当前没有可用的供应商！',
    'Currently there are {count} records in the database dating from {dating}.' => '从 {dating} 到目前为止数据库有 {count} 条记录。',
    'Dashboard' => '<strong>主面板</strong>',
    'Date input format' => '日期输入格式',
    'Default Expire Time (in seconds)' => '过期时间(以秒为单位)',
    'Default language' => '缺省语言',
    'Default pagination size (Entries per page)' => '默认分页大小（条目每页）',
    'Default stream content order' => '默认流内容顺序',
    'Delete' => '删除',
    'E-Mail' => '电子邮件',
    'E-Mail sender address' => '发送者邮件地址',
    'E-Mail sender name' => '发送者姓名',
    'E.g. http://example.com/humhub' => '例如 http://example.com/humhub',
    'Edit OEmbed provider' => '修改 OEmbed 供应商',
    'Enable user friendship system' => '启用用户友好系统',
    'Enabled' => '失效',
    'Enabled OEmbed providers' => '可用的 OEmbed 供应商',
    'Endpoint Url' => '端点 Url',
    'File' => '文件',
    'Firstname Lastname (e.g. John Doe)' => '姓 名 (例如 John Doe)',
    'Friendship' => '好友',
    'General' => '一般',
    'General Settings' => '一般设置',
    'HTML tracking code' => 'HTML的跟踪代码',
    'Here you can configurate the registration behaviour and additinal user settings of your social network.' => '在这里你可以为你的社交网络平台配置用户注册行为和附加用户信息',
    'Here you can configure basic settings of your social network.' => '在这里，你可以配置你的社交平台的基本设置。',
    'Horizontal scrolling images on a mobile device' => '在移动设备上的水平滚动图像',
    'Last visit' => '最后访问',
    'Logo upload' => 'LOGO上传',
    'Mail Transport Type' => '邮件传输类型',
    'Maximum allowed age for logs.' => '日志允许的最长时间。',
    'Maximum upload file size (in MB)' => '最大上传文件大小（MB）',
    'Name of the application' => '应用名称',
    'No Proxy Hosts' => '无代理主机',
    'Notification Settings' => '通知设置',
    'Old logs can significantly increase the size of your database while providing little information.' => '旧日志会明显增加您的数据库的大小，同时提供很少的信息。',
    'PHP reported a maximum of {maxUploadSize} MB' => 'PHP最大上传大小 {maxUploadSize} MB',
    'Password' => '密码',
    'Port' => '端口',
    'Port number' => '端口号',
    'Save' => '保存',
    'Save & Flush Caches' => '保存并删除缓存',
    'Saved' => '保 存',
    'Saved and flushed cache' => '保存并清除缓存',
    'Server' => '服务器',
    'Show introduction tour for new users' => '新用户显示向导',
    'Show user profile post form on dashboard' => '在控制面板上显示用户属性文章',
    'Sort by creation date' => '按创建日期排序',
    'Sort by update date' => '按更新日期排序',
    'Theme' => '主题',
    'These settings refer to advanced topics of your social network.' => '设置你的社交网络的高级主题',
    'These settings refer to the appearance of your social network.' => '设置你的社交网络的外观',
    'Use %url% as placeholder for URL. Format needs to be JSON. (e.g. http://www.youtube.com/oembed?url=%url%&format=json)' => '使用 %url% 作为 URL 的占位符。 合格应该为JSON。 (例如 http://www.youtube.com/oembed?url=%url%&format=json)',
    'Use X-Sendfile for File Downloads' => '使用x-sendfile文件下载',
    'User' => '用户',
    'User Settings' => '用户设置',
    'Username' => '用户名',
    'Username (e.g. john)' => '用户名(例如 John)',
    'You can add a statistic code snippet (HTML) - which will be added to all rendered pages.' => '你可以添加一个统计HTML代码段，此代码段将添加到所有的渲染页。',
    'You\'re using no logo at the moment. Upload your logo now.' => '你当前还没有LOGO。现在上传LOGO。',
    'never' => '从不',
    '"My Spaces" Sorting' => '',
    '<strong>Confirm</strong> icon deletion' => '',
    '<strong>Confirm</strong> topic deletion' => '',
    'APC(u)' => '',
    'Access Token' => '',
    'Access token is not provided yet.' => '',
    'Add Topic' => '',
    'Add custom info text for maintenance mode. Displayed on the login page.' => '',
    'Add individual info text...' => '',
    'Configuration (Use settings from configuration file)' => '',
    'Convert to global topic' => '',
    'Could not send test email.' => '',
    'Custom DSN' => '',
    'Custom sort order (alphabetical if not defined)' => '',
    'Custom sort order can be defined in the Space advanced settings.' => '',
    'DSN' => '',
    'DSN Examples:' => '',
    'Default Timezone' => '',
    'Do you really want to delete this topic?' => '',
    'E-Mail reply-to' => '',
    'Embedded content requires the user\'s consent to be loaded' => '',
    'Enable maintenance mode' => '',
    'Exclude media files from stream attachment list' => '',
    'Fixed format (dd/mm/yyyy) - Example: {example}' => '',
    'Global topics can be used by all users in all Spaces. They make it easier for you to define consistent keywords throughout your entire network. If users have already created topics in Spaces, you can also convert them to global topics here.' => '',
    'Icon upload' => '',
    'Inserted script tags must contain a nonce. e.g. {code}' => '',
    'Maintenance mode' => '',
    'Maintenance mode restricts access to the platform and immediately logs out all users except Admins.' => '',
    'Mobile appearance' => '',
    'No Delivery (Debug Mode, Save as file)' => '',
    'No caching' => '',
    'Optional. Default reply address for system emails like notifications.' => '',
    'PHP (Use settings of php.ini file)' => '',
    'PHP APC(u) Extension missing - Type not available!' => '',
    'Prevent client caching of following scripts' => '',
    'Provider Name' => '',
    'Redis' => '',
    'Regular expression by which the link match will be checked.' => '',
    'Save & Test' => '',
    'Saved and sent test email to: {address}' => '',
    'Test message' => '',
    'Topic has been deleted!' => '',
    'Topics' => '',
    'Url Pattern' => '',
    'Use SMTPS' => '',
    'User Display Name' => '',
    'User Display Name Subtitle' => '',
    'You can find more configuration options here:' => '',
    'You\'re using no icon at the moment. Upload your logo now.' => '',
    'e.g. 25 (for SMTP) or 465 (for SMTPS)' => '',
    'e.g. localhost' => '',
    'e.g. smtps://user:pass@smtp.example.com:port' => '',
];

==> humhub-1.18.0.zip: humhub-1.18.0/protected/humhub/modules/admin/messages/zh-CN/settings.php <==
<?php

return [
    '1 month' => '1个月',
    '1 week' => '1周',
    '1 year' => '1年',
    '2 weeks' => '两周',
    '3 months' => '3个月',
    '6 months' => '6个月',
    '<strong>Confirm</strong> image deletion' => '<strong>确认</strong> 删除图片',
    'Add OEmbed provider' => '增加 OEmbed 供应商',
    'Add new provider' => '增加新的供应商',
    'Advanced Settings' => '高级设置',
    'Allow Self-Signed Certificates?' => '允许自己签名的证书吗？',
    'Allowed file extensions' => '允许文件扩展名',
    'Appearance Settings' => '外观设置',
    'Auto format based on user language - Example: {example}' => '根据用户语言自动格式化 - 例如：{example}',
    'Back to overview' => '返回概览',
    'Base URL' => '基础URL',
    'Comma separated list. Leave empty to allow all.' => '逗号分割列表。留空为允许所有。',
    'Currently no provider active!' => '当前没有可用的供应商！',
    'Currently there are {count} records in the database dating from {dating}.' => '从 {dating} 到目前为止数据库有 {count} 条记录。',
    'Dashboard' => '<strong>主面板</strong>',
    'Date input format' => '日期输入格式',
    'Default' => '默认',
    'Default language' => '缺省语言',
    'Default pagination size (Entries per page)' => '默认分页大小（条目每页）',
    'Default stream content order' => '默认流内容顺序',
    'Delete' => '删除',
    'E-Mail' => '电子邮件',
    'E-Mail sender address' => '发送者邮件地址',
    'E-Mail sender name' => '发送者姓名',
    'E.g. http://example.com/humhub' => '例如 http://example.com/humhub',
    'Edit OEmbed provider' => '修改 OEmbed 供应商',
    'Enable user friendship system' => '启用用户友好系统',
    'Enabled' => '失效',
    'Enabled OEmbed providers' => '可用的 OEmbed 供应商',
    'Endpoint Url' => '端点 Url',
    'Firstname Lastname (e.g. John Doe)' => '姓 名 (例如 John Doe)',
    'Friendship' => '好友',
    'General' => '一般',
    'General Settings' => '一般设置',
    'HTML tracking code' => 'HTML的跟踪代码',
    'Here you can configurate the registration behaviour and additinal user settings of your social network.' => '在这里你可以为你的社交网络平台配置用户注册行为和附加用户信息',
    'Here you can configure basic settings of your social network.' => '在这里，你可以配置你的社交平台的基本设置。',
    'Last visit' => '最后访问',
    'Logo upload' => 'LOGO上传',
    'Mail Transport Type' => '邮件传输类型',
    'Maximum allowed age for logs.' => '日志允许的最长时间。',
    'Maximum upload file size (in MB)' => '最大上传文件大小（MB）',
    'Name of the application' => '应用名称',
    'No Proxy Hosts' => '无代理主机',
    'Notification Settings' => '通知设置',
    'Old logs can significantly increase the size of your database while providing little information.' => '旧日志会明显增加您的数据库的大小，同时提供很少的信息。',
    'PHP reported a maximum of {maxUploadSize} MB' => 'PHP最大上传大小 {maxUploadSize} MB',
    'Password' => '密码',
    'Port' => '端口',
    'Port number' => '端口号',
    'Save' => '保存',
    'Server' => '服务器',
    'Show introduction tour for new users' => '新用户显示向导',
    'Show user profile post form on dashboard' => '在控制面板上显示用户属性文章',
    'Sort by creation date' => '按创建日期排序',
    'Sort by update date' => '按更新日期排序',
    'Theme' => '主题',
    'These settings refer to advanced topics of your social network.' => '设置你的社交网络的高级主题',
    'These settings refer to the appearance of your social network.' => '设置你的社交网络的外观',
    'Use %url% as placeholder for URL. Format needs to be JSON. (e.g. http://www.youtube.com/oembed?url=%url%&format=json)' => '使用 %url% 作为 URL 的占位符。 合格应该为JSON。 (例如 http://www.youtube.com/oembed?url=%url%&format=json)',
    'Use X-Sendfile for File Downloads' => '使用x-sendfile文件下载',
    'User' => '用户',
    'User Settings' => '用户设置',
    'Username' => '用户名',
    'Username (e.g. john)' => '用户名(例如 John)',
    'You can add a statistic code snippet (HTML) - which will be added to all rendered pages.' => '你可以添加一个统计HTML代码段，此代码段将添加到所有的渲染页。',
    'You\'re using no logo at the moment. Upload your logo now.' => '你当前还没有LOGO。现在上传LOGO。',
    'never' => '从不',
    '"My Spaces" Sorting' => '',
    '<strong>Confirm</strong> icon deletion' => '',
    '<strong>Confirm</strong> topic deletion' => '',
    '<strong>Mobile App</strong> Debug Page' => '',
    'A dedicated image can be uploaded in the Appearance admin page.' => '',
    'Accent color' => '',
    'Access Token' => '',
    'Access token is not provided yet.' => '',
    'Add Topic' => '',
    'Add custom info text for maintenance mode. Displayed on the login page.' => '',
    'Add individual info text...' => '',
    'Allow establishing verified connections with the mobile app to enable Android app links and iOS universal links and redirect web content to the mobile app.' => '',
    'Caches flushed successfully' => '',
    'Cannot compile SCSS to CSS:' => '',
    'Configuration (Use settings from configuration file)' => '',
    'Convert to global topic' => '',
    'Could not send test email.' => '',
    'Custom DSN' => '',
    'Custom SCSS' => '',
    'Custom sort order (alphabetical if not defined)' => '',
    'Custom sort order can be defined in the Space advanced settings.' => '',
    'DSN' => '',
    'DSN Examples:' => '',
    'Danger color' => '',
    'Dark color' => '',
    'Debug' => '',
    'Default Timezone' => '',
    'Do you really want to delete this topic?' => '',
    'Domain URLs to whitelist, separated by comma' => '',
    'E-Mail reply-to' => '',
    'E.g. URLs of the SSO service providers' => '',
    'Email Header Image' => '',
    'Embedded content requires the user\'s consent to be loaded' => '',
    'Enable Link Redirection Service' => '',
    'Enable maintenance mode' => '',
    'Exclude media files from stream attachment list' => '',
    'Fixed format (dd/mm/yyyy) - Example: {example}' => '',
    'Flush Caches' => '',
    'Global topics can be used by all users in all Spaces. They make it easier for you to define consistent keywords throughout your entire network. If users have already created topics in Spaces, you can also convert them to global topics here.' => '',
    'Icon upload' => '',
    'In order for links to open in the app on mobile devices, rather than in the mobile browser, all links (e.g. notification emails) need to be routed through the HumHub proxy server.' => '',
    'Info color' => '',
    'Inserted script tags must contain a nonce. e.g. {code}' => '',
    'Invalid URL format: {domain}' => '',
    'Light color' => '',
    'Login Background' => '',
    'Maintenance mode' => '',
    'Maintenance mode restricts access to the platform and immediately logs out all users except Admins.' => '',
    'Mobile App' => '',
    'No Delivery (Debug Mode, Save as file)' => '',
    'Optional. Default reply address for system emails like notifications.' => '',
    'PHP (Use settings of php.ini file)' => '',
    'Please enable <a href="{url}" target="_blank">Pretty URLs</a> for proper working of the well-known files.' => '',
    'Primary color' => '',
    'Provider Name' => '',
    'Recommended minimum height: {recommendedMinHeight}px (minimum {minWidth} x {minHeight} px).' => '',
    'Recommended size: {recommendedWidth} × {recommendedHeight}px (minimum {minWidth} x {minHeight} px).' => '',
    'Regular expression by which the link match will be checked.' => '',
    'Save & Test' => '',
    'Saved and sent test email to: {address}' => '',
    'Secondary color' => '',
    'Show network name instead of logo in email header' => '',
    'Success color' => '',
    'Test message' => '',
    'Theme customization' => '',
    'Topic has been deleted!' => '',
    'Topics' => '',
    'URL to the file {fileNameLink}' => '',
    'Url Pattern' => '',
    'Use SMTPS' => '',
    'Use Sassy CSS syntax (SCSS)' => '',
    'User Display Name' => '',
    'User Display Name Subtitle' => '',
    'Warning color' => '',
    'Well-known file {fileName}' => '',
    'Well-known files' => '',
    'You can find more configuration options here:' => '',
    'You\'re using no icon at the moment. Upload your logo now.' => '',
    'e.g. 25 (for SMTP) or 465 (for SMTPS)' => '',
    'e.g. localhost' => '',
    'e.g. smtps://user:pass@smtp.example.com:port' => '',
];
